==> oauth-1.0.0-20190319.042656-349-sources.jar: org/gcube/portal/oauth/cache/CacheBean.java <==
package org.gcube.portal.oauth.cache;


/**
 * A cache bean object for oauth support
 * @author Costantino Perciante at ISTI-CNR (costantino.perciante@isti.cnr.it)
 */
public class CacheBean {

	private String token;
	private String scope;
	private String redirectUri;
	private String clientId;
	private Long insertTime;
	private static final int TOKEN_TTL = 1000 * 10;
	
	/**
	 * @param token
	 * @param scope
	 * @param redirectUri
	 * @param clientId
	 * @param insertTime
	 */
	public CacheBean(String token, String scope, String redirectUri,
			String clientId, Long insertTime) {
		super();
		this.token = token;
		this.scope = scope;
		this.redirectUri = redirectUri;
		this.clientId = clientId;
		this.insertTime = insertTime;
	}

	public String getScope() {
		return scope;
	}

	public void setScope(String scope) {
		this.scope = scope;
	}

	public String getToken() {
		return token;
	}

	public void setToken(String token) {
		this.token = token;
	}

	public Long getInsertTime() {
		return insertTime;
	}

	public void setInsertTime(Long insertTime) {
		this.insertTime = insertTime;
	}

	public String getRedirectUri() {
		return redirectUri;
	}

	public void setRedirectUri(String redirectUri) {
		this.redirectUri = redirectUri;
	}

	public String getClientId() {
		return clientId;
	}

	public void setClientId(String clientId) {
		this.clientId = clientId;
	}

	@Override
	public String toString() {
		return "CacheBean [token=" + token + ", scope=" + scope
				+ ", redirectUri=" + redirectUri + ", clientId=" + clientId
				+ ", insertTime=" + insertTime + "]";
	}

	/**
	 * True if the code expired, false otherwise
	 * @return
	 */
	public static boolean isExpired(CacheBean bean){
		
		return System.currentTimeMillis() > TOKEN_TTL + bean.insertTime;
		
	}
	
}

==> oauth-1.1.0-20190821.074014-1-sources.jar: org/gcube/portal/oauth/cache/CacheBean.java <==
package org.gcube.portal.oauth.cache;


import java.io.Serializable;

/**
 * A cache bean object for oauth support
 * @author Costantino Perciante at ISTI-CNR (costantino.perciante@isti.cnr.it)
 * @author Massimiliano Assante, National Research Council of Italy (CNR) - ISTI
 */
@SuppressWarnings("serial")
public class CacheBean implements Serializable {

	private String token;
	private String scope;
	private String redirectUri;
	private String clientId;
	
	public CacheBean() {
		super();
	}

	/**
	 * @param token
	 * @param scope
	 * @param redirectUri
	 * @param clientId
	 * @param insertTime
	 */
	public CacheBean(String token, String scope, String redirectUri, String clientId) {
		super();
		this.token = token;
		this.scope = scope;
		this.redirectUri = redirectUri;
		this.clientId = clientId;
	}

	public String getScope() {
		return scope;
	}

	public void setScope(String scope) {
		this.scope = scope;
	}

	public String getToken() {
		return token;
	}

	public void setToken(String token) {
		this.token = token;
	}

	public String getRedirectUri() {
		return redirectUri;
	}

	public void setRedirectUri(String redirectUri) {
		this.redirectUri = redirectUri;
	}

	public String getClientId() {
		return clientId;
	}

	public void setClientId(String clientId) {
		this.clientId = clientId;
	}

	@Override
	public String toString() {
		StringBuilder builder = new StringBuilder();
		builder.append("CacheBean [token=");
		builder.append(token);
		builder.append(", scope=");
		builder.append(scope);
		builder.append(", redirectUri=");
		builder.append(redirectUri);
		builder.append(", clientId=");
		builder.append(clientId);
		builder.append("]");
		return builder.toString();
	}	
}
